# Setup
```bash
cd packages/cerillo-python
# create virtual environment
python -m venv .venv
# linux and mac activate virtual env
source .venv/bin/activate
# windows activate virtual env
source .venv/Scripts/activate
# install dependencies (uses pyproject.toml)
pip install .
```

# Testing
Uses pytest for testing
Install with:
`pip install .[dev]`
Then run:
`pytest`